@@ -83,7 +83,9 @@ void recently_used_add (char *filename);
 
 int board_window_append_board (window_board_t *win, board *b); /* returns number of appended board */
 void board_window_init ();
-void board_window_set_style (window_board_t *win, int style);
+void board_window_set_style (window_board_t *win, int style, int card_width);
+void board_window_apply_style (window_board_t *win);
+
 void board_statusbar(char *text);
 
 /* stubs for calls from gui */
